USPSSdk class

Constructors

USPSSdk({required String userID})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userID String
final

Methods

cityStateLookup({required int zip5}) Future<USPSAddress>
domesticRates({required String uspsServiceType, required int zipOrigination, required int zipDestination, required double pounds, required double ounces, double width = 0, double height = 0, double length = 0, double value = 0, dynamic uspsContainer = ""}) Future<DomesticRates>
internationalRates({required String uspsServiceType, required int zipOrigination, required double pounds, required double ounces, required String country, double width = 0, double height = 0, double length = 0, double value = 0, dynamic uspsContainer = ""}) Future<InternationalRates>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trackAndConfirm({required String trackID}) Future<String>
validate({required USPSAddress address}) Future<USPSAddress>
zipCodeLookupAPI({String firmName = "", String address1 = "", required String address2, String city = "", String state = "", String urbanization = "", String zip5 = "", String zip4 = ""}) Future<USPSAddress>

Operators

operator ==(Object other) bool
The equality operator.
inherited